@@ -1,7 +1,7 @@
 /*
  * libev simple C++ wrapper classes
  *
- * Copyright (c) 2007 Marc Alexander Lehmann <libev@schmorp.de>
+ * Copyright (c) 2007,2008 Marc Alexander Lehmann <libev@schmorp.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modifica-
@@ -58,7 +58,8 @@ namespace ev {
 
   typedef ev_tstamp tstamp;
 
-  enum {
+  enum
+  {
     UNDEF    = EV_UNDEF,
     NONE     = EV_NONE,
     READ     = EV_READ,
@@ -72,27 +73,30 @@ namespace ev {
     CHECK    = EV_CHECK,
     PREPARE  = EV_PREPARE,
     FORK     = EV_FORK,
+    ASYNC    = EV_ASYNC,
     EMBED    = EV_EMBED,
+#   undef ERROR // some systems stupidly #define ERROR
     ERROR    = EV_ERROR,
   };
 
   enum
   {
-    AUTO = EVFLAG_AUTO,
-    NOENV = EVFLAG_NOENV,
+    AUTO      = EVFLAG_AUTO,
+    NOENV     = EVFLAG_NOENV,
     FORKCHECK = EVFLAG_FORKCHECK,
-    SELECT = EVBACKEND_SELECT,
-    POLL = EVBACKEND_POLL,
-    EPOLL = EVBACKEND_EPOLL,
-    KQUEUE = EVBACKEND_KQUEUE,
-    DEVPOLL = EVBACKEND_DEVPOLL,
-    PORT = EVBACKEND_PORT
+
+    SELECT    = EVBACKEND_SELECT,
+    POLL      = EVBACKEND_POLL,
+    EPOLL     = EVBACKEND_EPOLL,
+    KQUEUE    = EVBACKEND_KQUEUE,
+    DEVPOLL   = EVBACKEND_DEVPOLL,
+    PORT      = EVBACKEND_PORT
   };
 
   enum
   {
     NONBLOCK = EVLOOP_NONBLOCK,
-    ONESHOT = EVLOOP_ONESHOT
+    ONESHOT  = EVLOOP_ONESHOT
   };
 
   enum how_t
@@ -563,13 +567,13 @@ namespace ev {
 
   #if EV_MULTIPLICITY
     #define EV_CONSTRUCT(cppstem,cstem)	                                                \
-      (EV_PX = get_default_loop ()) throw ()                                         \
+      (EV_PX = get_default_loop ()) throw ()                                            \
         : base<ev_ ## cstem, cppstem> (EV_A)                                            \
       {                                                                                 \
       }
   #else
     #define EV_CONSTRUCT(cppstem,cstem)                                                 \
-      () throw ()                                                                    \
+      () throw ()                                                                       \
       {                                                                                 \
       }
   #endif
@@ -580,19 +584,19 @@ namespace ev {
                                                                                         \
   struct cppstem : base<ev_ ## cstem, cppstem>                                          \
   {                                                                                     \
-    void start () throw ()                                                           \
+    void start () throw ()                                                              \
     {                                                                                   \
       ev_ ## cstem ## _start (EV_A_ static_cast<ev_ ## cstem *>(this));                 \
     }                                                                                   \
                                                                                         \
-    void stop () throw ()                                                            \
+    void stop () throw ()                                                               \
     {                                                                                   \
       ev_ ## cstem ## _stop (EV_A_ static_cast<ev_ ## cstem *>(this));                  \
     }                                                                                   \
                                                                                         \
     cppstem EV_CONSTRUCT(cppstem,cstem)                                                 \
                                                                                         \
-    ~cppstem () throw ()                                                             \
+    ~cppstem () throw ()                                                                \
     {                                                                                   \
       stop ();                                                                          \
     }                                                                                   \
@@ -603,7 +607,7 @@ namespace ev {
                                                                                         \
     cppstem (const cppstem &o);                                                         \
                                                                                         \
-    cppstem & operator =(const cppstem &o);                                             \
+    cppstem &operator =(const cppstem &o);                                              \
                                                                                         \
   public:
 
@@ -748,10 +752,17 @@ namespace ev {
 
   #if EV_EMBED_ENABLE
   EV_BEGIN_WATCHER (embed, embed)
+    void set (struct ev_loop *embedded_loop) throw ()
+    {
+      int active = is_active ();
+      if (active) stop ();
+      ev_embed_set (static_cast<ev_embed *>(this), embedded_loop);
+      if (active) start ();
+    }
+
     void start (struct ev_loop *embedded_loop) throw ()
     {
-      stop ();
-      ev_embed_set (static_cast<ev_embed *>(this), embedded_loop);
+      set (embedded_loop);
       start ();
     }
 
@@ -768,6 +779,22 @@ namespace ev {
   EV_END_WATCHER (fork, fork)
   #endif
 
+  #if EV_ASYNC_ENABLE
+  EV_BEGIN_WATCHER (async, async)
+    void set () throw () { }
+
+    void send () throw ()
+    {
+      ev_async_send (EV_A_ static_cast<ev_async *>(this));
+    }
+
+    bool async_pending () throw ()
+    {
+      return ev_async_pending (static_cast<ev_async *>(this));
+    }
+  EV_END_WATCHER (async, async)
+  #endif
+
   #undef EV_PX
   #undef EV_PX_
   #undef EV_CONSTRUCT
