@@ -29,9 +29,8 @@
 # include <X11/Xft/Xft.h>
 #endif
 
-#include "iom.h"
+#include "ev_cpp.h"
 
-#include "rxvtlib.h"
 #include "rxvtutil.h"
 
 #include "callback.h"
@@ -62,12 +61,13 @@ enum {
   XA_NET_WM_NAME,
   XA_NET_WM_ICON_NAME,
   XA_NET_WM_PING,
+  XA_NET_WM_ICON,
 #endif
 #if USE_XIM
   XA_WM_LOCALE_NAME,
   XA_XIM_SERVERS,
 #endif
-#if TRANSPARENT
+#if ENABLE_TRANSPARENCY
   XA_XROOTPMAP_ID,
   XA_ESETROOT_PMAP_ID,
 #endif
@@ -76,7 +76,7 @@ enum {
   XA_XEMBED_INFO,
 #endif
 #if !ENABLE_MINIMAL
-  // these are usually allocated by other subsystens, but we do it
+  // these are usually allocated by other subsystems, but we do it
   // here to avoid a server roundtrip.
   XA_SCREEN_RESOURCES,
   XA_XDCCC_LINEAR_RGB_CORRECTION,
@@ -102,7 +102,31 @@ struct rxvt_display;
 struct im_watcher;
 struct xevent_watcher;
 
-struct refcounted {
+template<class watcher>
+struct event_vec : vector<watcher *>
+{
+  void erase_unordered (unsigned int pos)
+  {
+    watcher *w = (*this)[this->size () - 1];
+    this->pop_back ();
+
+    if (!this->empty ())
+      if (((*this)[pos] = w)) // '=' is correct!
+        w->active = pos + 1;
+  }
+};
+
+struct rxvt_watcher
+{
+  int active; /* 0 == inactive, else index into respective vector */
+
+  bool is_active () { return active; }
+
+  rxvt_watcher () : active (0) { }
+};
+
+struct refcounted
+{
   int referenced;
   char *id;
 
@@ -113,7 +137,8 @@ struct refcounted {
 };
 
 template<class T>
-struct refcache : vector<T *> {
+struct refcache : vector<T *>
+{
   T *get (const char *id);
   void put (T *obj);
   void clear ();
@@ -128,7 +153,8 @@ struct refcache : vector<T *> {
 
 struct rxvt_screen;
 
-struct rxvt_drawable {
+struct rxvt_drawable
+{
   rxvt_screen *screen;
   Drawable drawable;
   operator Drawable() { return drawable; }
@@ -154,7 +180,8 @@ struct rxvt_drawable {
 /////////////////////////////////////////////////////////////////////////////
 
 #ifdef USE_XIM
-struct rxvt_xim : refcounted {
+struct rxvt_xim : refcounted
+{
   void destroy ();
   rxvt_display *display;
 
@@ -167,7 +194,8 @@ struct rxvt_xim : refcounted {
 };
 #endif
 
-struct rxvt_screen {
+struct rxvt_screen
+{
   rxvt_display *display;
   Display *dpy;
   int depth;
@@ -189,10 +217,12 @@ struct rxvt_screen {
   void clear ();
 };
 
-struct rxvt_display : refcounted {
-  io_manager_vec<xevent_watcher> xw;
+struct rxvt_display : refcounted
+{
+  event_vec<xevent_watcher> xw;
 
-  io_watcher x_ev; void x_cb (io_watcher &w, short revents);
+  ev::prepare flush_ev; void flush_cb (ev::prepare &w, int revents);
+  ev::io      x_ev    ; void x_cb     (ev::io      &w, int revents);
 
 #ifdef USE_XIM
   refcache<rxvt_xim> xims;
@@ -219,7 +249,11 @@ struct rxvt_display : refcounted {
   void ref_next ();
   ~rxvt_display ();
 
-  void flush ();
+  void flush ()
+  {
+    flush_ev.start ();
+  }
+
   Atom atom (const char *name);
   void set_selection_owner (rxvt_term *owner);
 
@@ -236,16 +270,13 @@ struct rxvt_display : refcounted {
 };
 
 #ifdef USE_XIM
-struct im_watcher : watcher, callback<void (void)> {
-  template<class O, class M>
-  im_watcher (O object, M method)
-  : callback<void (void)> (object, method)
-  { }
-
+struct im_watcher : rxvt_watcher, callback<void (void)>
+{
   void start (rxvt_display *display)
   {
     display->reg (this);
   }
+
   void stop (rxvt_display *display)
   {
     display->unreg (this);
@@ -253,19 +284,16 @@ struct im_watcher : watcher, callback<void (void)> {
 };
 #endif
 
-struct xevent_watcher : watcher, callback<void (XEvent &)> {
+struct xevent_watcher : rxvt_watcher, callback<void (XEvent &)>
+{
   Window window;
 
-  template<class O, class M>
-  xevent_watcher (O object, M method)
-  : callback<void (XEvent &)> (object, method)
-  { }
-
   void start (rxvt_display *display, Window window)
   {
     this->window = window;
     display->reg (this);
   }
+
   void stop (rxvt_display *display)
   {
     display->unreg (this);
@@ -278,7 +306,8 @@ extern refcache<rxvt_display> displays;
 
 typedef unsigned long Pixel;
 
-struct rgba {
+struct rgba
+{
   unsigned short r, g, b, a;
 
   enum { MIN_CC = 0x0000, MAX_CC  = 0xffff };
@@ -291,7 +320,8 @@ struct rgba {
   { }
 };
 
-struct rxvt_color {
+struct rxvt_color
+{
 #if XFT
   XftColor c;
 #else
@@ -303,17 +333,34 @@ struct rxvt_color {
   bool operator == (const rxvt_color &b) const { return Pixel (*this) == Pixel (b); }
   bool operator != (const rxvt_color &b) const { return Pixel (*this) != Pixel (b); }
 
+  bool is_opaque () const
+  {
+#if XFT
+    return c.color.alpha == rgba::MAX_CC;
+#else
+    return 1;
+#endif
+  }
+
   bool alloc (rxvt_screen *screen, const rgba &color);
   void free (rxvt_screen *screen);
 
   void get (rgba &color);
   void get (XColor &color);
- 
+
   bool set (rxvt_screen *screen, const char *name);
   bool set (rxvt_screen *screen, const rgba &color);
 
   void fade (rxvt_screen *screen, int percent, rxvt_color &result, const rgba &to = rgba (0, 0, 0));
 };
 
+#if TRACE_PIXMAPS
+Pixmap trace_XCreatePixmap (const char *file, int line, Display *dpy, Window r, unsigned int w, unsigned int h, unsigned int d);
+void trace_XFreePixmap (const char *file, int line, Display *dpy, Pixmap p);
+
+# define XCreatePixmap(dpy,r,w,h,d) trace_XCreatePixmap (__FILE__,__LINE__,dpy,r,w,h,d)
+# define XFreePixmap(dpy,p) trace_XFreePixmap (__FILE__,__LINE__,dpy,p)
+#endif
+
 #endif
 
