@@ -110,7 +110,7 @@ will be called when the toggle changes, with the new boolean value as
 first argument.
 
 The following will add an entry C<myoption> that changes
-C<$self->{myoption}>:
+C<< $self->{myoption} >>:
 
    push @{ $self->{term}{option_popup_hook} }, sub {
       ("my option" => $myoption, sub { $self->{myoption} = $_[0] })
@@ -305,6 +305,12 @@ extension will actually grab a physical key just for this function.
 If you want a quake-like animation, tell your window manager to do so
 (fvwm can do it).
 
+=item overlay-osc
+
+This extension implements some OSC commands to display timed popups on the
+screen - useful for status displays from within scripts. You have to read
+the sources for more info.
+
 =item block-graphics-to-ascii
 
 A not very useful example of filtering all text output to the terminal
@@ -543,29 +549,42 @@ It is called before lines are scrolled out (so rows 0 .. min ($lines - 1,
 $nrow - 1) represent the lines to be scrolled out). C<$saved> is the total
 number of lines that will be in the scrollback buffer.
 
-=item on_osc_seq $term, $op, $args
+=item on_osc_seq $term, $op, $args, $resp
 
 Called on every OSC sequence and can be used to suppress it or modify its
-behaviour.  The default should be to return an empty list. A true value
+behaviour. The default should be to return an empty list. A true value
 suppresses execution of the request completely. Make sure you don't get
-confused by recursive invocations when you output an osc sequence within
+confused by recursive invocations when you output an OSC sequence within
 this callback.
 
 C<on_osc_seq_perl> should be used for new behaviour.
 
-=item on_osc_seq_perl $term, $string
+=item on_osc_seq_perl $term, $args, $resp
 
 Called whenever the B<ESC ] 777 ; string ST> command sequence (OSC =
 operating system command) is processed. Cursor position and other state
 information is up-to-date when this happens. For interoperability, the
-string should start with the extension name and a colon, to distinguish
-it from commands for other extensions, and this might be enforced in the
-future.
+string should start with the extension name (sans -osc) and a semicolon,
+to distinguish it from commands for other extensions, and this might be
+enforced in the future.
+
+For example, C<overlay-osc> uses this:
+
+   sub on_osc_seq_perl {
+      my ($self, $osc, $resp) = @_;
+
+      return unless $osc =~ s/^overlay;//;
+
+      ... process remaining $osc string
+   }
 
 Be careful not ever to trust (in a security sense) the data you receive,
 as its source can not easily be controlled (e-mail content, messages from
 other users on the same system etc.).
 
+For responses, C<$resp> contains the end-of-args separator used by the
+sender.
+
 =item on_add_lines $term, $string
 
 Called whenever text is about to be output, with the text as argument. You
@@ -595,8 +614,8 @@ you cannot just toggle rendition bits, but only set them.
 
 =item on_refresh_begin $term
 
-Called just before the screen gets redrawn. Can be used for overlay
-or similar effects by modify terminal contents in refresh_begin, and
+Called just before the screen gets redrawn. Can be used for overlay or
+similar effects by modifying the terminal contents in refresh_begin, and
 restoring them in refresh_end. The built-in overlay and selection display
 code is run after this hook, and takes precedence.
 
@@ -1093,7 +1112,7 @@ work.
 
 =cut
 
-our $VERSION = 1;
+our $VERSION = '3.4';
 
 $INC{"urxvt/anyevent.pm"} = 1; # mark us as there
 push @AnyEvent::REGISTRY, [urxvt => urxvt::anyevent::];
@@ -1134,20 +1153,6 @@ sub DESTROY {
    $_[0][1]->stop;
 }
 
-sub condvar {
-   bless \my $flag, urxvt::anyevent::
-}
-
-sub broadcast {
-   ${$_[0]}++;
-}
-
-sub wait {
-   unless (${$_[0]}) {
-      Carp::croak "AnyEvent->condvar blocking wait unsupported in urxvt, use a non-blocking API";
-   }
-}
-
 sub one_event {
    Carp::croak "AnyEvent->one_event blocking wait unsupported in urxvt, use a non-blocking API";
 }
@@ -1278,7 +1283,7 @@ are supported in every build, please see the source file F</src/rsinc.h>
 to see the actual list:
 
   answerbackstring backgroundPixmap backspace_key boldFont boldItalicFont
-  borderLess color cursorBlink cursorUnderline cutchars delete_key
+  borderLess chdir color cursorBlink cursorUnderline cutchars delete_key
   display_name embed ext_bwidth fade font geometry hold iconName
   imFont imLocale inputMethod insecure int_bwidth intensityStyles
   italicFont jumpScroll lineSpace loginShell mapAlert meta8 modifier
@@ -1296,7 +1301,7 @@ to see the actual list:
 sub resource($$;$) {
    my ($self, $name) = (shift, shift);
    unshift @_, $self, $name, ($name =~ s/\s*\+\s*(\d+)$// ? $1 : 0);
-   &urxvt::term::_resource
+   goto &urxvt::term::_resource
 }
 
 =item $value = $term->x_resource ($pattern)
@@ -1389,12 +1394,14 @@ The methods currently supported on C<urxvt::overlay> objects are:
 
 =over 4
 
-=item $overlay->set ($x, $y, $text, $rend)
+=item $overlay->set ($x, $y, $text[, $rend])
 
 Similar to C<< $term->ROW_t >> and C<< $term->ROW_r >> in that it puts
 text in rxvt-unicode's special encoding and an array of rendition values
 at a specific position inside the overlay.
 
+If C<$rend> is missing, then the rendition will not be changed.
+
 =item $overlay->hide
 
 If visible, hide the overlay, but do not destroy it.
@@ -1613,10 +1620,9 @@ Used after changing terminal contents to display them.
 
 =item $text = $term->ROW_t ($row_number[, $new_text[, $start_col]])
 
-Returns the text of the entire row with number C<$row_number>. Row C<0>
-is the topmost terminal line, row C<< $term->$ncol-1 >> is the bottommost
-terminal line. The scrollback buffer starts at line C<-1> and extends to
-line C<< -$term->nsaved >>. Nothing will be returned if a nonexistent line
+Returns the text of the entire row with number C<$row_number>. Row C<< $term->top_row >>
+is the topmost terminal line, row C<< $term->nrow-1 >> is the bottommost
+terminal line. Nothing will be returned if a nonexistent line
 is requested.
 
 If C<$new_text> is specified, it will replace characters in the current
@@ -1824,7 +1830,7 @@ the session.
 
 =item ($type,$format,$octets) = $term->XGetWindowProperty ($window, $property)
 
-=item $term->XChangeWindowProperty ($window, $property, $type, $format, $octets)
+=item $term->XChangeProperty ($window, $property, $type, $format, $octets)
 
 =item $term->XDeleteProperty ($window, $property)
 
